@@ -13,6 +13,10 @@
 # under the License.
 
 
+from magnum.common import exception
+from magnum.i18n import _
+
+
 class HelmException(Exception):
     pass
 
@@ -47,3 +51,15 @@ class OpenStackClusterSubnetNotReady(OpenStackClusterNotReady):
 
 class ClusterAPIReconcileTimeout(Exception):
     pass
+
+
+class ClusterMasterCountEven(Exception):
+    pass
+
+
+class OpenstackFlavorInvalidName(exception.InvalidName):
+    message = _("Expected a flavor name but received flavor id %(flavor)s.")
+
+
+class MachineDeploymentNotFound(exception.ObjectNotFound):
+    message = _("MachineDeployment %(name)s not found.")
