@@ -19,7 +19,9 @@ import subprocess
 from oslo_log import log as logging
 
 import magnum_cluster_api.privsep
+from magnum_cluster_api import conf
 
+CONF = conf.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -41,7 +43,7 @@ def start(config_file):
 def reload():
     """Reload HAproxy configuration"""
 
-    with open("/var/run/haproxy.pid", "r") as fd:
+    with open(CONF.proxy.haproxy_pid_path, "r") as fd:
         pid = int(fd.read().strip())
 
     os.kill(pid, signal.SIGUSR2)
